@@ -1,15 +1,14 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
-# pylint: disable=line-too-long
-""""Visit folder tree with CSAF or CVRF documents, validate the latter, and generate reports."""
-import pathlib
+"""Visit folder tree with CSAF or CVRF documents, validate the latter, and generate reports."""
 import os
+import pathlib
 import sys
 
 import csaf_lint.lint as lint
 
-DEBUG_VAR = "CSL_DEBUG"
-DEBUG = bool(os.getenv(DEBUG_VAR))
+DEBUG_VAR = 'CSL_DEBUG'
+DEBUG = bool(os.getenv(DEBUG_VAR, ''))
 
 
 # pylint: disable=expression-not-assigned
@@ -26,7 +25,7 @@ def main(argv=None, debug=None):
             if not embedded:
                 embedded = True
             else:
-                print("ERROR: embedding only works for none or all.")
+                print('ERROR: embedding only works for none or all.')
                 sys.exit(2)
 
     return lint.main(argv, embedded=embedded, debug=debug)
